% bessel evaluates the zero-order bessel function */
% and its derivative for complex argument z. */
% void bessel( complex double z, complex double *j0, complex double *j0p )
function [j0,j0p] = bessel0(z)
%   int k, i, ib, iz, miz;
%   static int m[101], init = FALSE;
%   static double a1[25], a2[25];
%   double tst, zms;
%   complex double p0z, p1z, q0z, q1z, zi, zi2, zk, cz, sz, j0x, j0px;
m = zeros(101,1);
init = 0;
a1 = zeros(25,1);
a2 = zeros(25,1);

% C1 =	-.02457850915;
% C2 =	.3674669052;
C3 =	.7978845608;
P10 =	.0703125;
P20 =	.1121520996;
Q10 =	.125;
Q20 =	.0732421875;
P11 =	.1171875;
P21 =	.1441955566;
Q11	= .375;
Q21 =	.1025390625;
POF =	.7853981635;

% initialization of constants */
if ~init 
  for j = 1:25
    a1(j) = -.25/(j^2);
    a2(j) = 1/(j + 1);
  end

  for j = 1:101 
    tst = 1;
    for k = 1:24 
   	  init = k;
	    tst = tst*-j*a1(k); 
	    if tst < 1E-6 
	      break;
      end
    end

    m(j) = init; 
  end % for

  init = 1; % init = TRUE;
end  % if

zms = z*conj(z);
if zms <= 1E-12 
  j0 = 1; 
  j0p = -.5*z; 
  return
end

ib=0;
if (zms <= 37.21)
  if (zms > 36)
    ib = 1;
  end

  % /* series expansion */
  iz = floor(zms) + 1; 
  miz = m(iz); 
  j0 = 1;  
  j0p = j0;  
  zk = j0; 
  zi = z^2; 

  for k = 1:miz 
    zk = zk * a1(k)*zi; 
    j0 = j0 + zk; 
    j0p = j0p + a2(k)*zk; 
  end
  j0p = j0p*-.5*z; 

  if (ib == 0)
    return
  end

  j0x = j0; 
  j0px = j0p; 
end

  % /* asymptotic expansion */
  zi = 1/z; 
  zi2 = zi^2; 
  p0z = 1 + (P20*zi2 - P10)*zi2; 
  p1z = 1 + (P11 - P21*zi2)*zi2; 
  q0z = (Q20*zi2 - Q10)*zi; 
  q1z = (Q11 - Q21*zi2)*zi; 
  zk = exp(i*(z - POF)); 
  zi2 = 1/zk; 
  cz = .5*(zk + zi2); 
  sz = i*.5*(zi2 - zk); 
  zk = C3*sqrt(zi); 
  j0 = zk*(p0z*cz - q0z*sz); 
  j0p = -zk*(p1z*sz + q1z*cz); 

  if (ib == 0)
    return
  end

  zms = cos((sqrt(zms) - 6)*pi*10); 
  j0 = .5*(j0x*(1 + zms) + j0*(1 - zms)); 
  j0p = .5*(j0px*(1 + zms)+ j0p*(1 - zms)); 

  return